# Web Visualization

## Build Ruckig WASM Module

To build the Ruckig Wasm Module, call
```
zsh doc/web-gui/make_wasm.sh
```
from the project root.


## Local Development

To develop the web-based GUI locally, run
```
npm install
npm run start
```
and open the specified link in the browser.
